Learn R Programming

NUCOMBog (version 1.0.4.2)

runNUCOM: Run NUCOMBog

Description

Code to run NUCOMBog on a single core.

Usage

runNUCOM(setup, parameters = NULL)

Arguments

setup

The setup structure created by setup_NUCOM function needs to be inserted here, for more information see the setup_NUCOM function help, by typing "?NUCOMBog::setup_NUCOM".

parameters

The parameters which are used in the model. If no parameter values are given the default values will be used. The parameters have to have the format of a dataframe with colum names: "names" and "values". See example data available via the testcopydata function. The default parameters are from Heijmans et al. 2008.

References

Heijmans, M., Mauquoy, D., van Geel, B., and Berendse, F. (2008). Long-term effects of climate change on vegetation and carbon dynamics in peat bogs. Journal of Vegetation Science, 19(3)

Examples

Run this code
# NOT RUN {
names<-c("CO2ref","gram_Beta","eric_MaxGr")
initialParameters <- c(380,0.5,65)
initialParameters<-data.frame(names,initialParameters)
names(initialParameters)<-c("names","values")

runNUCOM(setup = test_setup_singlecore,parameters=initialParameters)

## with predefined parameters:
runnucom(setup = test_setup_singlecore,parameters=NULL)
# }

Run the code above in your browser using DataLab